@@ -23,7 +23,7 @@ use utf8;
 
 use FindBin qw($Bin);
 use lib "$Bin/../../lib";
-use Google::Ads::GoogleAds::Client;
+use Google::Ads::GoogleAds::GoogleAdsClient;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::Utils::FieldMasks;
 use Google::Ads::GoogleAds::V2::Resources::CustomerClientLink;
@@ -89,7 +89,7 @@ sub link_manager_to_client {
     $api_client_link_response->{result}{resourceName};
 
   printf "Extended an invitation from the manager customer %d to the " .
-    "client customer %d with the customer client link resource name: %s.\n",
+    "client customer %d with the customer client link resource name: '%s'.\n",
     $manager_customer_id, $api_client_customer_id,
     $api_client_link_resource_name;
 
@@ -136,7 +136,7 @@ sub link_manager_to_client {
       operations => [$manager_link_operation]});
 
   printf "The client customer %d accepted the invitation with " .
-    "the customer manager link resource name: %s.\n",
+    "the customer manager link resource name: '%s'.\n",
     $api_client_customer_id,
     $manager_link_response->{results}[0]{resourceName};
 
@@ -149,7 +149,8 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V2"});
+my $api_client =
+  Google::Ads::GoogleAds::GoogleAdsClient->new({version => "V2"});
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
