@@ -23,7 +23,7 @@ use utf8;
 
 use FindBin qw($Bin);
 use lib "$Bin/../../lib";
-use Google::Ads::GoogleAds::Client;
+use Google::Ads::GoogleAds::GoogleAdsClient;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::V2::Resources::AdGroupAd;
 use Google::Ads::GoogleAds::V2::Resources::Ad;
@@ -98,7 +98,7 @@ sub add_responsive_search_ad {
       customerId => $customer_id,
       operations => [$ad_group_ad_operation]});
 
-  printf "Created responsive search ad %s.\n",
+  printf "Created responsive search ad '%s'.\n",
     $ad_group_ad_response->{results}[0]{resourceName};
 
   return 1;
@@ -118,7 +118,8 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V2"});
+my $api_client =
+  Google::Ads::GoogleAds::GoogleAdsClient->new({version => "V2"});
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
