@@ -23,7 +23,7 @@ use utf8;
 
 use FindBin qw($Bin);
 use lib "$Bin/../../lib";
-use Google::Ads::GoogleAds::Client;
+use Google::Ads::GoogleAds::GoogleAdsClient;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use
   Google::Ads::GoogleAds::V2::Services::BillingSetupService::BillingSetupOperation;
@@ -65,7 +65,7 @@ sub remove_billing_setup {
     operation  => $billing_setup_operation
   });
 
-  printf "Removed billing setup with resource name: %s.\n",
+  printf "Removed billing setup with resource name: '%s'.\n",
     $billing_setup_response->{result}{resourceName};
 
   return 1;
@@ -77,7 +77,8 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V2"});
+my $api_client =
+  Google::Ads::GoogleAds::GoogleAdsClient->new({version => "V2"});
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
