@@ -23,7 +23,7 @@ use utf8;
 
 use FindBin qw($Bin);
 use lib "$Bin/../../lib";
-use Google::Ads::GoogleAds::Client;
+use Google::Ads::GoogleAds::GoogleAdsClient;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::V2::Resources::CampaignDraft;
 use
@@ -70,7 +70,7 @@ sub add_campaign_draft {
       customerId => $customer_id,
       operations => [$campaign_draft_operation]});
 
-  printf "Added a campaign draft with resource name: %s.\n",
+  printf "Added a campaign draft with resource name: '%s'.\n",
     $campaign_draft_response->{results}[0]{resourceName};
 
   return 1;
@@ -82,7 +82,8 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V2"});
+my $api_client =
+  Google::Ads::GoogleAds::GoogleAdsClient->new({version => "V2"});
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
