@@ -23,7 +23,7 @@ use utf8;
 
 use FindBin qw($Bin);
 use lib "$Bin/../../lib";
-use Google::Ads::GoogleAds::Client;
+use Google::Ads::GoogleAds::GoogleAdsClient;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::V2::Resources::CampaignBudget;
 use Google::Ads::GoogleAds::V2::Resources::Campaign;
@@ -108,7 +108,7 @@ sub create_mutate_job {
     })->{resourceName};
 
   printf
-    "Created a mutate job with resource name: %s.\n",
+    "Created a mutate job with resource name: '%s'.\n",
     $mutate_job_resource_name;
 
   return $mutate_job_resource_name;
@@ -144,7 +144,7 @@ sub run_mutate_job {
     $mutate_job_service->run({resourceName => $mutate_job_resource_name});
 
   printf
-    "Mutate job with resource name %s has been executed.\n",
+    "Mutate job with resource name '%s' has been executed.\n",
     $mutate_job_resource_name;
 
   return $mutate_job_lro;
@@ -166,7 +166,7 @@ sub poll_mutate_job {
 sub fetch_and_print_results {
   my ($mutate_job_service, $mutate_job_resource_name) = @_;
 
-  printf "Mutate job with resource name %s has finished. " .
+  printf "Mutate job with resource name '%s' has finished. " .
     "Now, printing its results...\n",
     $mutate_job_resource_name;
 
@@ -468,7 +468,8 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V2"});
+my $api_client =
+  Google::Ads::GoogleAds::GoogleAdsClient->new({version => "V2"});
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
