@@ -23,7 +23,7 @@ use utf8;
 
 use FindBin qw($Bin);
 use lib "$Bin/../../lib";
-use Google::Ads::GoogleAds::Client;
+use Google::Ads::GoogleAds::GoogleAdsClient;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::V2::Resources::CampaignExperiment;
 use Google::Ads::GoogleAds::V2::Enums::CampaignExperimentTrafficSplitTypeEnum
@@ -66,7 +66,7 @@ sub create_campaign_experiment {
     });
 
   printf "Asynchronous request to create campaign experiment with " .
-    "resource name %s started.\n",
+    "resource name '%s' started.\n",
     $campaign_experiment_lro->{metadata}{campaignExperiment};
 
   printf "Waiting until operation completes.\n";
@@ -87,7 +87,7 @@ sub create_campaign_experiment {
     query      => $search_query
   });
 
-  printf "Experiment campaign %s finished creation.\n",
+  printf "Experiment campaign '%s' finished creation.\n",
     $search_response->{results}[0]{campaignExperiment}{experimentCampaign};
 
   return 1;
@@ -99,7 +99,8 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V2"});
+my $api_client =
+  Google::Ads::GoogleAds::GoogleAdsClient->new({version => "V2"});
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
