@@ -22,7 +22,7 @@ use utf8;
 
 use FindBin qw($Bin);
 use lib "$Bin/../../lib";
-use Google::Ads::GoogleAds::Client;
+use Google::Ads::GoogleAds::GoogleAdsClient;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::V2::Resources::CampaignBudget;
 use Google::Ads::GoogleAds::V2::Enums::BudgetDeliveryMethodEnum qw(STANDARD);
@@ -69,8 +69,8 @@ sub graduate_campaign_experiment {
       customerId => $customer_id,
       operations => [$campaign_budget_operation]})->{results}[0]{resourceName};
 
-  printf
-    "Created new campaign budget %s to add to experiment during graduation.\n",
+  printf "Created new campaign budget '%s' to add to experiment" .
+    " during graduation.\n",
     $campaign_budget_resource_name;
 
   # Graduate the campaign using the campaign budget created above.
@@ -79,7 +79,7 @@ sub graduate_campaign_experiment {
     campaignBudget     => $campaign_budget_resource_name
   });
 
-  printf "Campaign experiment %s is now graduated.\n",
+  printf "Campaign experiment '%s' is now graduated.\n",
     $graduate_response->{graduatedCampaign};
 
   return 1;
@@ -91,7 +91,8 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V2"});
+my $api_client =
+  Google::Ads::GoogleAds::GoogleAdsClient->new({version => "V2"});
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
