@@ -25,7 +25,7 @@ use utf8;
 
 use FindBin qw($Bin);
 use lib "$Bin/../../lib";
-use Google::Ads::GoogleAds::Client;
+use Google::Ads::GoogleAds::GoogleAdsClient;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::V2::Resources::AdGroupAd;
 use Google::Ads::GoogleAds::V2::Resources::Ad;
@@ -166,7 +166,7 @@ sub request_exemption {
       customerId => $customer_id,
       operations => [$ad_group_ad_operation]});
 
-  printf "Successfully added an expanded text ad with resource name %s by " .
+  printf "Successfully added an expanded text ad with resource name '%s' by " .
     "requesting for policy violation exemption.\n",
     $ad_group_ad_response->{results}[0]{resourceName};
 }
@@ -177,7 +177,8 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V2"});
+my $api_client =
+  Google::Ads::GoogleAds::GoogleAdsClient->new({version => "V2"});
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(0);
