@@ -32,7 +32,7 @@ use utf8;
 
 use FindBin qw($Bin);
 use lib "$Bin/../../lib";
-use Google::Ads::GoogleAds::Client;
+use Google::Ads::GoogleAds::GoogleAdsClient;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::V2::Resources::AdGroupCriterion;
 use Google::Ads::GoogleAds::V2::Common::KeywordInfo;
@@ -105,7 +105,7 @@ sub handle_keyword_policy_violations {
         "non-policy related errors thrown.\n";
     }
   } else {
-    printf "Added a keyword with resource name %s.\n",
+    printf "Added a keyword with resource name '%s'.\n",
       $response->{results}[0]{resourceName};
   }
 
@@ -173,7 +173,7 @@ sub request_exemption {
       customerId => $customer_id,
       operations => [$ad_group_criterion_operation]});
 
-  printf "Successfully added a keyword with resource name %s by requesting " .
+  printf "Successfully added a keyword with resource name '%s' by requesting " .
     "for policy violation exemption.\n",
     $ad_group_criterion_response->{results}[0]{resourceName};
 }
@@ -184,7 +184,8 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V2"});
+my $api_client =
+  Google::Ads::GoogleAds::GoogleAdsClient->new({version => "V2"});
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(0);
