@@ -28,7 +28,7 @@ use utf8;
 
 use FindBin qw($Bin);
 use lib "$Bin/../../lib";
-use Google::Ads::GoogleAds::Client;
+use Google::Ads::GoogleAds::GoogleAdsClient;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::V2::Resources::CampaignBudget;
 use Google::Ads::GoogleAds::V2::Resources::Campaign;
@@ -130,7 +130,7 @@ sub add_campaign_budget {
       customerId => $customer_id,
       operations => [$campaign_budget_operation]})->{results}[0]{resourceName};
 
-  printf "Added a budget with resource name: %s.\n",
+  printf "Added a budget with resource name: '%s'.\n",
     $campaign_budget_resource_name;
 
   return $campaign_budget_resource_name;
@@ -185,7 +185,7 @@ sub add_standard_shopping_campaign {
       customerId => $customer_id,
       operations => [$campaign_operation]})->{results}[0]{resourceName};
 
-  printf "Added a standard shopping campaign with resource name: %s.\n",
+  printf "Added a standard shopping campaign with resource name: '%s'.\n",
     $campaign_resource_name;
 
   return $campaign_resource_name;
@@ -216,7 +216,7 @@ sub add_shopping_product_ad_group {
       customerId => $customer_id,
       operations => [$ad_group_operation]})->{results}[0]{resourceName};
 
-  printf "Added a product shopping ad group with resource name: %s.\n",
+  printf "Added a product shopping ad group with resource name: '%s'.\n",
     $ad_group_resource_name;
 
   return $ad_group_resource_name;
@@ -248,7 +248,7 @@ sub add_shopping_product_ad_group_ad {
       customerId => $customer_id,
       operations => [$ad_group_ad_operation]})->{results}[0]{resourceName};
 
-  printf "Added a product shopping ad group ad with resource name: %s.\n",
+  printf "Added a product shopping ad group ad with resource name: '%s'.\n",
     $ad_group_ad_resource_name;
 
   return $ad_group_ad_resource_name;
@@ -293,7 +293,7 @@ sub add_default_shopping_listing_group {
   )->{results}[0]{resourceName};
 
   printf "Added an ad group criterion containing a listing group " .
-    "with resource name: %s.\n", $ad_group_criterion_resource_name;
+    "with resource name: '%s'.\n", $ad_group_criterion_resource_name;
 
   return $ad_group_criterion_resource_name;
 }
@@ -304,7 +304,8 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V2"});
+my $api_client =
+  Google::Ads::GoogleAds::GoogleAdsClient->new({version => "V2"});
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
