@@ -40,7 +40,7 @@ use constant POST => "POST";
 # Class::Std-style attributes. Need to be kept in the same line.
 # These need to go in the same line for older Perl interpreters to understand.
 my %api_client_of : ATTR(:name<api_client> :default<>);
-my %__user_agent_of : ATTR(:name<__user_agent> :default<>);
+my %__lwp_agent_of : ATTR(:name<__lwp_agent> :default<>);
 my %__json_coder_of : ATTR(:name<__json_coder> :default<>);
 
 # Automatically called by Class::Std after the values for all the attributes
@@ -48,7 +48,7 @@ my %__json_coder_of : ATTR(:name<__json_coder> :default<>);
 sub START {
   my ($self, $ident) = @_;
 
-  $__user_agent_of{$ident} ||= LWP::UserAgent->new();
+  $__lwp_agent_of{$ident} ||= LWP::UserAgent->new();
   # The 'pretty' attribute should be enabled for more readable form in the log.
   # The 'convert_blessed' attributed should be enabled to convert blessed objects.
   $__json_coder_of{$ident} ||= JSON::XS->new->utf8->pretty->convert_blessed;
@@ -56,7 +56,9 @@ sub START {
 
 # Sends a HTTP request to Google Ads API server and handles the response.
 sub call {
-  my ($self, $http_method, $request_path, $request_body, $response_type) = @_;
+  my ($self, $http_method, $request_path, $request_body, $response_type,
+    $content_callback)
+    = @_;
 
   my $api_client = $self->get_api_client();
 
@@ -137,19 +139,38 @@ sub call {
 
   utf8::is_utf8 $http_request and utf8::encode $http_request;
 
-  my $user_agent = $self->get___user_agent();
+  my $lwp_agent = $self->get___lwp_agent();
 
-  # Set up timeout and proxy for the user agent.
-  $user_agent->timeout(Google::Ads::GoogleAds::Constants::DEFAULT_LWP_TIMEOUT);
+  # Set up http timeout and proxy for the lwp agent.
+  my $http_timeout = $api_client->get_http_timeout();
+  $lwp_agent->timeout(
+      $http_timeout
+    ? $http_timeout
+    : Google::Ads::GoogleAds::Constants::DEFAULT_HTTP_TIMEOUT
+  );
   my $proxy = $api_client->get_proxy();
   $proxy
-    ? $user_agent->proxy(['http', 'https'], $proxy)
-    : $user_agent->env_proxy;
+    ? $lwp_agent->proxy(['http', 'https'], $proxy)
+    : $lwp_agent->env_proxy;
 
   # Keep track of the last sent HTTP request.
   $api_client->set_last_request($http_request);
 
-  my $http_response = $user_agent->request($http_request);
+  # Send HTTP request with optional content callback handler (for search stream).
+  my $http_response = undef;
+  if ($content_callback) {
+    $http_response = $lwp_agent->request($http_request, $content_callback);
+    # The callback handler is not invoked when the response status is error.
+    if ($http_response->is_error) {
+      # The error response content returned by the search stream interface is
+      # enclosed in square brackets, deviating from normal GoogleAdsException.
+      # Remove the leading and trailing square brackets in the response content,
+      # to make it operable in the subsequent steps (logging, exception handling).
+      $http_response->content($http_response->decoded_content =~ s/^\[|\]$//gr);
+    }
+  } else {
+    $http_response = $lwp_agent->request($http_request);
+  }
 
   # Keep track of the last received HTTP response.
   $api_client->set_last_response($http_response);
@@ -176,7 +197,8 @@ sub call {
   ##############################################################################
   # Step 4: Return the decoded object or exception from the response content.
   ##############################################################################
-  my $response_body = $json_coder->decode($response_content);
+  my $response_body =
+    $response_content ? $json_coder->decode($response_content) : {};
 
   if ($http_response->is_success) {
     # Bless the JSON format response to the response type class.
@@ -196,12 +218,15 @@ sub _get_http_headers {
   my ($self) = @_;
 
   my $api_client = $self->get_api_client();
+  my $user_agent = $api_client->get_user_agent();
 
   my $headers = [
     "Content-Type",
     "application/json; charset=utf-8",
     "user-agent",
-    Google::Ads::GoogleAds::Constants::DEFAULT_USER_AGENT,
+    $user_agent
+    ? $user_agent
+    : Google::Ads::GoogleAds::Constants::DEFAULT_USER_AGENT,
     "x-goog-api-client",
     Google::Ads::GoogleAds::Constants::DEFAULT_USER_AGENT,
     "developer-token",
@@ -229,16 +254,16 @@ AdGroupService, etc.
 
 =head1 SYNOPSIS
 
-  use Google::Ads::GoogleAds::Client;
+  use Google::Ads::GoogleAds::GoogleAdsClient;
 
-  my $api_client = Google::Ads::GoogleAds::Client->new({version => "V2"});
+  my $api_client = Google::Ads::GoogleAds::GoogleAdsClient->new({version => "V1"});
 
   my $campaign_service = $api_client->CampaignService();
 
 =head1 ATTRIBUTES
 
-Each service instance is initialized by L<Google::Ads::GoogleAds::Client>,and
-these attributes are set automatically.
+Each service instance is initialized by L<Google::Ads::GoogleAds::GoogleAdsClient>,
+and these attributes are set automatically.
 
 Alternatively, there is a get_ and set_ method associated with each attribute
 for retrieving or setting them dynamically.
@@ -247,8 +272,8 @@ for retrieving or setting them dynamically.
 
 =head2 api_client
 
-A reference to the L<Google::Ads::GoogleAds::Client>, holding the API credentials
-and configurations.
+A reference to the L<Google::Ads::GoogleAds::GoogleAdsClient>, holding the API
+credentials and configurations.
 
 =head1 METHODS
 
@@ -284,6 +309,8 @@ be encoded into JSON string for a HTTP POST request. Should be C<undef> for GET
 I<response_type>: The class name of the expected response. A instance of this class
 will be returned if the request succeeds.
 
+I<content_callback>: The optional streaming content callback method.
+
 =back
 
 =head3 Returns
@@ -291,7 +318,7 @@ will be returned if the request succeeds.
 A instance of the class defined by the C<response_type> argument, or a
 L<Google::Ads::GoogleAds::GoogleAdsException> object if an error has occurred at the
 server side by default. However if the C<die_on_faults> flag is set to true in
-L<Google::Ads::GoogleAds::Client>, the service will issue a die() with error
+L<Google::Ads::GoogleAds::GoogleAdsClient>, the service will issue a die() with error
 message on API errors.
 
 =head2 _get_http_headers
