@@ -24,13 +24,13 @@ use File::HomeDir;
 use File::Spec::Functions;
 
 # Main version number that the rest of the modules pick up off of.
-our $VERSION = qv("2.1.0");
+our $VERSION = qv("2.2.0");
 
 use constant DEFAULT_PROPERTIES_FILE =>
   catfile(File::HomeDir->my_home, "googleads.properties");
 
-# Default Google Ads API version used if the API client is created without a
-# specified version.
+# Default Google Ads API version used if the GoogleAdsClient is created without
+# a specified version.
 use constant DEFAULT_API_VERSION => "V2";
 
 # Default OAuth2 scope for Google Ads API.
@@ -49,7 +49,7 @@ use constant DEFAULT_SERVICE_ADDRESS => "https://googleads.googleapis.com/";
 use constant DEFAULT_USER_AGENT => "gl-perl/" . substr($^V, 1);
 
 # Default LWP::UserAgent timeout.
-use constant DEFAULT_LWP_TIMEOUT => 3600;
+use constant DEFAULT_HTTP_TIMEOUT => 3600;
 
 # The LongRunning.OperationSerivce version.
 use constant OPERATION_SERVICE_VERSION => "V2";
